@@ -3,14 +3,14 @@
 
 from arghandler import subcmd, ArgumentHandler
 
-from . import __version__
-from .bloc.bloc_cmd import BlocCommand
-from .json_to_dart.json_cmd import JsonCommand
-from .model.ui_config import UiConfig
-from .network.network_cmd import NetworkCommand
-from .parser_helpers import *
-from .printer import *
-from .ui.figma_ui_generator import FigmaUIGenerator
+from kntgen import __version__
+from kntgen.bloc.bloc_cmd import BlocCommand
+from kntgen.json_to_dart.json_cmd import JsonCommand
+from kntgen.model.ui_config import UiConfig
+from kntgen.network.network_cmd import NetworkCommand
+from kntgen.parser_helpers import *
+from kntgen.printer import *
+from kntgen.ui.figma_ui_generator import FigmaUIGenerator
 
 
 @subcmd('sample', help=DefinedCmd.HELP_CMD_SAMPLE)
