@@ -1,6 +1,6 @@
 import subprocess
 
-from .printer import *
+from printer import *
 
 FLUTTER_FORMAT = 'flutter format .'
 FLUTTER_GEN = 'flutter pub run build_runner build --delete-conflicting-outputs'
